impl_try_from_value_str

Macro impl_try_from_value_str 

macro_rules! impl_try_from_value_str {
    ($type:ty) => { ... };
}
Implement TryFromValue for the given type by converting the Value to a String, then using T’s FromStr implementation to convert to T.

This could be a derive macro, but decl is much simpler