RenderedChunks

Struct RenderedChunks 

pub struct RenderedChunks<V>(/* private fields */);
Outcome of rendering the individual chunks of a template. This is an intermediate output type that can be resolved into a variety of final output types.

Implementations

Source

impl<V: RenderValue> RenderedChunks<V>

pub fn into_chunks(self) -> Vec<RenderedChunk<V>>

Get the inner list of chunks

pub fn chunks(&self) -> &[RenderedChunk<V>]

Get the inner chunks as a slice

pub fn iter(&self) -> impl Iterator<Item = &RenderedChunk<V>>

Get an iterator over references to the chunks

pub fn unpack(self) -> Result<V, Self>

Unpack this output into a single value

If the output is a single dynamic chunk, unpack it into a scalar value. Otherwise, return Err(self).

Source

impl RenderedChunks<Value>

pub fn try_into_value(self) -> Result<Value, RenderError>

Collect the rendered chunks into a Value by these rules:

  • If the template is a single dynamic chunk, return the output of that chunk, which may be any type of Value
  • Any other template will be rendered to a string by stringifying each dynamic chunk and concatenating them all together
  • If rendering to a string fails because the bytes are not valid UTF-8, concatenate into a bytes object instead
pub fn try_into_bytes(self) -> Result<Bytes, RenderError>

Collect the rendered chunks into a byte string

If any chunk is an error, return an error.

Source

impl RenderedChunks<ValueStream>

pub fn stream_source(&self) -> Option<&StreamSource>

If this output is a single chunk and that chunk is a stream, get the source of the stream

pub fn has_stream(&self) -> bool

Does this output contain any stream chunks?

pub async fn try_collect_value(self) -> Result<Value, RenderError>

Collect the rendered chunks into a Value by these rules:

  • If the template is a single dynamic chunk, return the output of that chunk, which may be any type of Value
  • If there are any streams, resolve them to bytes
  • Any other template will be rendered to a string by stringifying each dynamic chunk and concatenating them all together
  • If rendering to a string fails because the bytes are not valid UTF-8, concatenate into a bytes object instead
pub fn try_into_stream( self, ) -> Result<impl Stream<Item = Result<Bytes, RenderError>> + Send, RenderError>

Convert this output into a byte stream. Each chunk will be yielded as a separate Bytes output from the stream, except for inner stream chunks, which can yield any number of values based on their implementation. Return Err if any of the rendered chunks are errors.