macro_rules! impl_try_from_value_str {
($type:ty) => { ... };
}Expand description
Implement TryFromValue for the given type by converting the Value to a
String, then using T’s FromStr implementation to convert to T.
This could be a derive macro, but decl is much simpler