pub struct RenderedChunks<V>(/* private fields */);Expand description
Outcome of rendering the individual chunks of a template. This is an intermediate output type that can be resolved into a variety of final output types.
Implementations
Sourceimpl<V: RenderValue> RenderedChunks<V>
impl<V: RenderValue> RenderedChunks<V>
Sourcepub fn into_chunks(self) -> Vec<RenderedChunk<V>>
pub fn into_chunks(self) -> Vec<RenderedChunk<V>>
Get the inner list of chunks
Sourcepub fn chunks(&self) -> &[RenderedChunk<V>]
pub fn chunks(&self) -> &[RenderedChunk<V>]
Get the inner chunks as a slice
Sourcepub fn iter(&self) -> impl Iterator<Item = &RenderedChunk<V>>
pub fn iter(&self) -> impl Iterator<Item = &RenderedChunk<V>>
Get an iterator over references to the chunks
Sourceimpl RenderedChunks<Value>
impl RenderedChunks<Value>
Sourcepub fn try_into_value(self) -> Result<Value, RenderError>
pub fn try_into_value(self) -> Result<Value, RenderError>
Collect the rendered chunks into a Value by these rules:
- If the template is a single dynamic chunk, return the output of that chunk, which may be any type of Value
- Any other template will be rendered to a string by stringifying each dynamic chunk and concatenating them all together
- If rendering to a string fails because the bytes are not valid UTF-8, concatenate into a bytes object instead
Sourcepub fn try_into_bytes(self) -> Result<Bytes, RenderError>
pub fn try_into_bytes(self) -> Result<Bytes, RenderError>
Collect the rendered chunks into a byte string
If any chunk is an error, return an error.
Sourceimpl RenderedChunks<ValueStream>
impl RenderedChunks<ValueStream>
Sourcepub fn stream_source(&self) -> Option<&StreamSource>
pub fn stream_source(&self) -> Option<&StreamSource>
If this output is a single chunk and that chunk is a stream, get the source of the stream
Sourcepub fn has_stream(&self) -> bool
pub fn has_stream(&self) -> bool
Does this output contain any stream chunks?
Sourcepub async fn try_collect_value(self) -> Result<Value, RenderError>
pub async fn try_collect_value(self) -> Result<Value, RenderError>
Collect the rendered chunks into a Value by these rules:
- If the template is a single dynamic chunk, return the output of that chunk, which may be any type of Value
- If there are any streams, resolve them to bytes
- Any other template will be rendered to a string by stringifying each dynamic chunk and concatenating them all together
- If rendering to a string fails because the bytes are not valid UTF-8, concatenate into a bytes object instead
Sourcepub fn try_into_stream(
self,
) -> Result<impl Stream<Item = Result<Bytes, RenderError>> + Send, RenderError>
pub fn try_into_stream( self, ) -> Result<impl Stream<Item = Result<Bytes, RenderError>> + Send, RenderError>
Convert this output into a byte stream. Each chunk will be yielded as a
separate Bytes output from the stream, except for inner stream chunks,
which can yield any number of values based on their implementation.
Return Err if any of the rendered chunks are errors.